==> lhcsmapi-1.3.229.tar.gz: lhcsmapi-1.3.229/lhcsmapi/analysis/decorators.py <==
from functools import wraps
import warnings
import pandas as pd
import numpy as np


def warning_on_one_line(message, category, filename, lineno, file=None, line=None):
    return '%s\n' % (message)


warnings.formatwarning = warning_on_one_line


def check_dataframe_empty(mode='all', warning='All provided DataFrames are missing, analysis skipped.'):
    def inner_function(func):
        @wraps(func)
        def wrapper(*args, **kw):
            if mode == 'all':
                cond = all([arg.empty for arg in args if isinstance(arg, pd.DataFrame)])
            elif mode == 'any':
                cond = any([arg.empty for arg in args if isinstance(arg, pd.DataFrame)])
            else:
                raise ValueError('Mode takes only values in [\'all\', \'any\'], got {}'.format(mode))

            if cond:
                warnings.warn(warning)
                return None
            else:
                return func(*args, **kw)

        return wrapper

    return inner_function


def check_nan_timestamp(return_type=pd.DataFrame,
                        warning='Input timestamp is NaN, query skipped returning default return_type.'):
    def inner_function(func):
        @wraps(func)
        def wrapper(*args, **kwargs):
            cond_arg = any([np.isnan(arg) for arg in args if isinstance(arg, float)])
            cond_kwarg = any([np.isnan(kwarg) for kwarg in kwargs.values() if isinstance(kwarg, float)])

            if cond_arg or cond_kwarg:
                warnings.warn('In function %s: %s' % (str(func).split(' ')[1], warning))
                return return_type
            else:
                return func(*args, **kwargs)

        return wrapper

    return inner_function


def check_nan_timestamp_signals(return_type=pd.DataFrame, signal_name='signal_names',
                                warning='Input timestamp is NaN, query skipped returning default return_type.'):
    def inner_function(func):
        @wraps(func)
        def wrapper(*args, **kwargs):
            cond_arg = any([np.isnan(arg) for arg in args if isinstance(arg, float)])
            cond_kwarg = any([np.isnan(kwarg) for kwarg in kwargs.values() if isinstance(kwarg, float)])

            if cond_arg or cond_kwarg:
                warnings.warn('In function %s: %s' % (str(func).split(' ')[1], warning))
                return [return_type]*len(kwargs[signal_name])
            else:
                return func(*args, **kwargs)

        return wrapper

    return inner_function

==> lhcsmapi-1.3.300.tar.gz: lhcsmapi-1.3.300/lhcsmapi/analysis/decorators.py <==
from functools import wraps
import warnings
import pandas as pd
import numpy as np

from lhcsmapi.pyedsl.FeatureBuilder import flatten_nested_lists


def warning_on_one_line(message, category, filename, lineno, file=None, line=None):
    return '%s\n' % (message)


warnings.formatwarning = warning_on_one_line


def check_dataframe_empty(mode='all', warning='All provided DataFrames are missing, analysis skipped.'):
    def inner_function(func):
        @wraps(func)
        def wrapper(*args, **kw):
            if mode == 'all':
                args_scalars = [arg.empty for arg in args if isinstance(arg, pd.DataFrame)]
                cond_scalar = all(args_scalars) if args_scalars else False
                args_list = flatten_nested_lists([arg for arg in args if isinstance(arg, list)])
                cond_vector = all([arg.empty for arg in args_list]) if args_list else False
                cond = cond_scalar or cond_vector
            elif mode == 'any':
                cond_scalar = any([arg.empty for arg in args if isinstance(arg, pd.DataFrame)]) if args else False
                args_list = flatten_nested_lists([arg for arg in args if isinstance(arg, list)])
                cond_vector = any([arg.empty for arg in args_list if isinstance(arg, pd.DataFrame)])
                cond = cond_scalar or cond_vector
            else:
                raise ValueError('Mode takes only values in [\'all\', \'any\'], got {}'.format(mode))

            if cond:
                warnings.warn(warning)
                return None
            else:
                return func(*args, **kw)

        return wrapper

    return inner_function


def check_nan_timestamp(return_type=pd.DataFrame,
                        warning='Input timestamp is NaN, query skipped returning default return_type.'):
    def inner_function(func):
        @wraps(func)
        def wrapper(*args, **kwargs):
            cond_arg = any([np.isnan(arg) for arg in args if isinstance(arg, float)])
            cond_kwarg = any([np.isnan(kwarg) for kwarg in kwargs.values() if isinstance(kwarg, float)])

            if cond_arg or cond_kwarg:
                warnings.warn('In function %s: %s' % (str(func).split(' ')[1], warning))
                return return_type
            else:
                return func(*args, **kwargs)

        return wrapper

    return inner_function


def check_nan_timestamp_signals(return_type=pd.DataFrame, signal_name='signal_names',
                                warning='Input timestamp is NaN, query skipped returning default return_type.'):
    def inner_function(func):
        @wraps(func)
        def wrapper(*args, **kwargs):
            cond_arg = any([np.isnan(arg) for arg in args if isinstance(arg, float)])
            cond_kwarg = any([np.isnan(kwarg) for kwarg in kwargs.values() if isinstance(kwarg, float)])

            if cond_arg or cond_kwarg:
                warnings.warn('In function %s: %s' % (str(func).split(' ')[1], warning))
                return [return_type]*len(kwargs[signal_name])
            else:
                return func(*args, **kwargs)

        return wrapper

    return inner_function
